@@ -135,7 +135,7 @@ struct GEMMI_DLL Mtz {
       // COMBAT sets BSCALE=1, but Pointless sets it to 0.
       //floats[43] = 1.f; // batch scale
     }
-    int number;
+    int number = 0;
     std::string title;
     std::vector<int> ints;
     std::vector<float> floats;
@@ -479,7 +479,7 @@ struct GEMMI_DLL Mtz {
 
   // Functions for reading MTZ headers and data.
 
-  void toggle_endiannes() {
+  void toggle_endianness() {
     same_byte_order = !same_byte_order;
     swap_eight_bytes(&header_offset);
   }
@@ -501,7 +501,7 @@ struct GEMMI_DLL Mtz {
     // BE is denoted by 1 and LE by 4.
     // If we get a value different than 1 and 4 we assume the native byte order.
     if ((buf[9] & 0xf0) == (is_little_endian() ? 0x10 : 0x40))
-      toggle_endiannes();
+      toggle_endianness();
 
     std::int32_t tmp_header_offset;
     std::memcpy(&tmp_header_offset, buf + 4, 4);
@@ -853,52 +853,11 @@ struct GEMMI_DLL Mtz {
   /// Similar to command EXPAND in SFTOOLS.
   void expand_to_p1();
 
-  // (for unmerged MTZ only) change HKL according to M/ISYM
-  bool switch_to_original_hkl() {
-    if (indices_switched_to_original)
-      return false;
-    if (!has_data())
-      fail("switch_to_original_hkl(): data not read yet");
-    const Column* col = column_with_label("M/ISYM");
-    if (col == nullptr || col->type != 'Y' || col->idx < 3)
-      return false;
-    std::vector<Op> inv_symops;
-    inv_symops.reserve(symops.size());
-    for (const Op& op : symops)
-      inv_symops.push_back(op.inverse());
-    for (size_t n = 0; n + col->idx < data.size(); n += columns.size()) {
-      int isym = static_cast<int>(data[n + col->idx]) & 0xFF;
-      const Op& op = inv_symops.at((isym - 1) / 2);
-      Miller hkl = op.apply_to_hkl(get_hkl(n));
-      int sign = (isym & 1) ? 1 : -1;
-      for (int i = 0; i < 3; ++i)
-        data[n+i] = static_cast<float>(sign * hkl[i]);
-    }
-    indices_switched_to_original = true;
-    return true;
-  }
+  /// (for unmerged MTZ only) change HKL according to M/ISYM
+  bool switch_to_original_hkl();
 
-  // (for unmerged MTZ only) change HKL to ASU equivalent and set ISYM
-  bool switch_to_asu_hkl() {
-    if (!indices_switched_to_original)
-      return false;
-    if (!has_data())
-      fail("switch_to_asu_hkl(): data not read yet");
-    const Column* col = column_with_label("M/ISYM");
-    if (col == nullptr || col->type != 'Y' || col->idx < 3 || !spacegroup)
-      return false;
-    size_t misym_idx = col->idx;
-    UnmergedHklMover hkl_mover(spacegroup);
-    for (size_t n = 0; n + col->idx < data.size(); n += columns.size()) {
-      Miller hkl = get_hkl(n);
-      int isym = hkl_mover.move_to_asu(hkl);  // modifies hkl
-      set_hkl(n, hkl);
-      float& misym = data[n + misym_idx];
-      misym = float(((int)misym & ~0xff) | isym);
-    }
-    indices_switched_to_original = false;
-    return true;
-  }
+  /// (for unmerged MTZ only) change HKL to ASU equivalent and set ISYM
+  bool switch_to_asu_hkl();
 
   Dataset& add_dataset(const std::string& name) {
     int id = 0;
@@ -1041,10 +1000,8 @@ struct GEMMI_DLL Mtz {
     columns.erase(columns.begin() + idx);
     for (size_t i = idx; i < columns.size(); ++i)
       --columns[i].idx;
-    for (size_t dest = idx, source = idx + 1; source < data.size(); ++source)
-      for (size_t i = 0; i < columns.size() && source < data.size(); ++i)
-        data[dest++] = data[source++];
-    data.resize(columns.size() * nreflections);
+    vector_remove_column(data, columns.size(), idx);
+    assert(columns.size() * nreflections == data.size());
   }
 
   template <typename Func>
@@ -1067,20 +1024,10 @@ struct GEMMI_DLL Mtz {
     size_t old_row_size = columns.size() - added;
     if (data.size() != old_row_size * nreflections)
       fail("Internal error");
-    data.resize(columns.size() * nreflections);
     size_t pos = pos_ == -1 ? old_row_size : (size_t) pos_;
     if (pos > old_row_size)
       fail("expand_data_rows(): pos out of range");
-    std::vector<float>::iterator dst = data.end();
-    for (int i = nreflections; i-- != 0; ) {
-      for (size_t j = old_row_size; j-- != pos; )
-        *--dst = data[i * old_row_size + j];
-      for (size_t j = added; j-- != 0; )
-        *--dst = NAN;
-      for (size_t j = pos; j-- != 0; )
-        *--dst = data[i * old_row_size + j];
-    }
-    assert(dst == data.begin());
+    vector_insert_columns(data, old_row_size, (size_t)nreflections, added, pos, NAN);
   }
 
   void set_data(const float* new_data, size_t n) {
