@@ -837,7 +837,7 @@ inline Op hall_matrix_symbol(const char* start, const char* end,
 }
 
 // Parses either short (0 0 1) or long notation (x,y,z+1/12)
-// but without multpliers (such as 1/2x) to keep things simple for now.
+// but without multipliers (such as 1/2x) to keep things simple for now.
 inline Op parse_hall_change_of_basis(const char* start, const char* end) {
   if (std::memchr(start, ',', end - start) != nullptr) // long symbol
     return parse_triplet(std::string(start, end));
@@ -1057,55 +1057,55 @@ inline Op::Tran nonzero_inversion_center(int space_group_number) {
 // Generated by tools/gen_sg_table.py.
 inline const char* get_basisop(int basisop_idx) {
   static const char* basisops[49] = {
-    "x,y,z",
-    "z,x,y",
-    "y,z,x",
-    "z,y,-x",
-    "x,y,-x+z",
-    "-x,z,y",
-    "-x+z,x,y",
-    "y,-x,z",
-    "y,-x+z,x",
-    "x-z,y,z",
-    "z,x-z,y",
-    "y,z,x-z",
-    "z,y,-x+z",
-    "x+z,y,-x",
-    "x+1/4,y+1/4,z",
-    "-x+z,z,y",
-    "-x,x+z,y",
-    "y,-x+z,z",
-    "y,-x,x+z",
-    "x+1/4,y-1/4,z",
-    "x-1/4,y-1/4,z-1/4",
-    "x-1/4,y-1/4,z",
-    "z,x-1/4,y-1/4",
-    "y-1/4,z,x-1/4",
-    "x-1/2,y-1/4,z+1/4",
-    "z+1/4,x-1/2,y-1/4",
-    "y-1/4,z+1/4,x-1/2",
-    "x+1/8,y+1/8,z+1/8",
-    "x+1/4,y-1/4,z+1/4",
-    "x-1/4,y+1/4,z",
-    "x+1/4,y+1/4,z+1/4",
-    "x,y+1/4,z+1/8",
-    "x-1/4,y+1/4,z+1/4",
-    "x-1/4,y+1/4,z-1/4",
-    "x-1/2,y+1/4,z+1/8",
-    "x-1/2,y+1/4,z-3/8",
-    "-y+z,x+z,-x+y+z",
-    "x-1/8,y-1/8,z-1/8",
-    "x+1/4,y+1/4,-x+z-1/4",
-    "x+1/4,y,z",
-    "x,y,z+1/4",
-    "-x,-y/2+z/2,y/2+z/2",
-    "-x/2+z/2,-y,x/2+z/2",
-    "x/2+y/2,x/2-y/2,-z",
-    "y/2+z/2,x/2+z/2,x/2+y/2",
-    "-x/2+y/2+z/2,x/2-y/2+z/2,x/2+y/2-z/2",
-    "-x/2+z,x/2,y",
-    "x-z/2,y,z/2",
-    "x/2+y/2,-x/2+y/2,z",
+    "x,y,z",  // 0
+    "z,x,y",  // 1
+    "y,z,x",  // 2
+    "z,y,-x",  // 3
+    "x,y,-x+z",  // 4
+    "-x,z,y",  // 5
+    "-x+z,x,y",  // 6
+    "y,-x,z",  // 7
+    "y,-x+z,x",  // 8
+    "x-z,y,z",  // 9
+    "z,x-z,y",  // 10
+    "y,z,x-z",  // 11
+    "z,y,-x+z",  // 12
+    "x+z,y,-x",  // 13
+    "x+1/4,y+1/4,z",  // 14
+    "-x+z,z,y",  // 15
+    "-x,x+z,y",  // 16
+    "y,-x+z,z",  // 17
+    "y,-x,x+z",  // 18
+    "x+1/4,y-1/4,z",  // 19
+    "x-1/4,y-1/4,z-1/4",  // 20
+    "x-1/4,y-1/4,z",  // 21
+    "z,x-1/4,y-1/4",  // 22
+    "y-1/4,z,x-1/4",  // 23
+    "x-1/2,y-1/4,z+1/4",  // 24
+    "z+1/4,x-1/2,y-1/4",  // 25
+    "y-1/4,z+1/4,x-1/2",  // 26
+    "x+1/8,y+1/8,z+1/8",  // 27
+    "x+1/4,y-1/4,z+1/4",  // 28
+    "x-1/4,y+1/4,z",  // 29
+    "x+1/4,y+1/4,z+1/4",  // 30
+    "x,y+1/4,z+1/8",  // 31
+    "x-1/4,y+1/4,z+1/4",  // 32
+    "x-1/4,y+1/4,z-1/4",  // 33
+    "x-1/2,y+1/4,z+1/8",  // 34
+    "x-1/2,y+1/4,z-3/8",  // 35
+    "-y+z,x+z,-x+y+z",  // 36
+    "x-1/8,y-1/8,z-1/8",  // 37
+    "x+1/4,y+1/4,-x+z-1/4",  // 38
+    "x+1/4,y,z",  // 39
+    "x,y,z+1/4",  // 40
+    "-x,-y/2+z/2,y/2+z/2",  // 41
+    "-x/2+z/2,-y,x/2+z/2",  // 42
+    "x/2+y/2,x/2-y/2,-z",  // 43
+    "y/2+z/2,x/2+z/2,x/2+y/2",  // 44
+    "-x/2+y/2+z/2,x/2-y/2+z/2,x/2+y/2-z/2",  // 45
+    "-x/2+z,x/2,y",  // 46
+    "x-z/2,y,z/2",  // 47
+    "x/2+y/2,-x/2+y/2,z",  // 48
   };
   return basisops[basisop_idx];
 }
