@@ -31,10 +31,12 @@ struct GEMMI_DLL Topo {
   struct Bond {
     const Restraints::Bond* restr;
     std::array<Atom*, 2> atoms;
-    double calculate() const { return atoms[0]->pos.dist(atoms[1]->pos); }
-    double calculate_z() const {
-      return std::abs(calculate() - restr->value) / restr->esd;
+    Asu asu;
+    double calculate() const {
+      return asu != Asu::Different ? atoms[0]->pos.dist(atoms[1]->pos) : NAN;
     }
+    double calculate_z_(double d) const { return std::abs(d - restr->value) / restr->esd; }
+    double calculate_z() const { return calculate_z_(calculate()); }
   };
   struct Angle {
     const Restraints::Angle* restr;
@@ -244,7 +246,7 @@ struct GEMMI_DLL Topo {
   double ideal_chiral_abs_volume(const Chirality &ch) const;
 
   std::vector<Rule> apply_restraints(const Restraints& rt,
-                                     Residue& res, Residue* res2,
+                                     Residue& res, Residue* res2, Asu asu,
                                      char altloc1, char altloc2, bool require_alt);
   void apply_restraints_from_link(Link& link, const MonLib& monlib);
 
@@ -310,5 +312,8 @@ prepare_topology(Structure& st, MonLib& monlib, size_t model_index,
 
 GEMMI_DLL std::unique_ptr<ChemComp> make_chemcomp_with_restraints(const Residue& res);
 
+GEMMI_DLL std::vector<AtomAddress> find_missing_atoms(const Topo& topo,
+                                                      bool including_hydrogen=false);
+
 } // namespace gemmi
 #endif
