@@ -10,14 +10,13 @@
 #include "gemmi/to_mmcif.hpp"  // for update_mmcif_block
 #include "gemmi/assembly.hpp"  // for ChainNameGenerator, transform_to_assembly
 #include "gemmi/pirfasta.hpp"  // for read_pir_or_fasta
-#include "gemmi/resinfo.hpp"   // for expand_protein_one_letter
 #include "gemmi/mmread_gz.hpp" // for read_structure_gz
 #include "gemmi/select.hpp"    // for Selection
+#include "gemmi/enumstr.hpp"   // for polymer_type_to_string
 
 #include <cstring>
 #include <iostream>
 #include <algorithm>           // for sort
-#include <map>
 
 #define GEMMI_PROG convert
 #include "options.h"
@@ -47,7 +46,7 @@ enum OptionIndex {
   FormatIn=AfterCifModOptions, FormatOut, CifStyle, AllAuth, BlockName,
   ExpandNcs, AsAssembly,
   RemoveH, RemoveWaters, RemoveLigWat, TrimAla, Select, Remove, ApplySymop,
-  ShortTer, Linkr, CopyRemarks, Minimal, ShortenCN, RenameChain,
+  Reframe, ShortTer, Linkr, CopyRemarks, Minimal, ShortenCN, RenameChain,
   ChangeCcdCode, SetSeq,
   SiftsNum, Biso, Anisou, SetCis, SegmentAsChain, OldPdb, ForceLabel
 };
@@ -107,9 +106,8 @@ const option::Descriptor Usage[] = {
   { ChangeCcdCode, 0, "", "monomer", Arg::ColonPair,
     "  --monomer=OLD:NEW  \tChange monomer name (CCD code) OLD to NEW." },
   { SetSeq, 0, "s", "", Arg::Required,
-    "  -s FILE  \tUse sequence from FILE (PIR or FASTA format), "
-    "which must contain either one sequence (for all chains) "
-    "or as many sequences as there are chains." },
+    "  -s FILE  \tUse sequence(s) from FILE in PIR or FASTA format. Each chain"
+    " is assigned the best matching sequence, if any." },
   { SiftsNum, 0, "", "sifts-num", Arg::None,
     "  --sifts-num  \tUse SIFTS-mapped position in UniProt sequence as sequence ID." },
   { Biso, 0, "B", "", Arg::Required,
@@ -129,6 +127,8 @@ const option::Descriptor Usage[] = {
     "  --remove=SEL  \tRemove the selection." },
   { ApplySymop, 0, "", "apply-symop", Arg::Required,
     "  --apply-symop=OP  \tApply symmetry operation (e.g. '-x,y+1/2,-z'." },
+  { Reframe, 0, "", "reframe", Arg::None,
+    "  --reframe  \tStandardize the coordinate system (frame)." },
   { ExpandNcs, 0, "", "expand-ncs", ConvArg::NcsChoice,
     "  --expand-ncs=dup|num|x  \tExpand strict NCS from in MTRIXn or"
     " _struct_ncs_oper. New chain names are the same, have added numbers,"
@@ -144,7 +144,7 @@ const option::Descriptor Usage[] = {
   { TrimAla, 0, "", "trim-to-ala", Arg::None,
     "  --trim-to-ala  \tTrim aminoacids to alanine." },
   { NoOp, 0, "", "", Arg::None,
-    "\nWhen output file is -, write to standard output." },
+    "\nWhen output file is -, write to standard output (default format: pdb)." },
   { 0, 0, 0, 0, 0, 0 }
 };
 
@@ -160,11 +160,26 @@ std::string format_as_string(CoorFormat format) {
   gemmi::unreachable();
 }
 
+std::string read_whole_file(std::istream& stream) {
+  constexpr std::size_t buf_size = 4096;
+  char buffer[buf_size];
+  stream.exceptions(std::ios_base::badbit);  // throw on fail/bad
+  std::string out;
+  while (stream) {
+    stream.read(buffer, buf_size);
+    out.append(buffer, stream.gcount());
+  }
+  return out;
+}
+
 void convert(gemmi::Structure& st,
              const std::string& output, CoorFormat output_type,
              const std::vector<option::Option>& options) {
   if (st.models.empty())
     gemmi::fail("No atoms in the input file. Wrong file format?");
+  if (st.ter_status == 'e')
+    std::cerr << "WARNING: TER records in the input PDB are clearly where they shouldn't be."
+                 "\nWARNING: Ignoring all TER records." << std::endl;
 
   for (const option::Option* opt = options[ChangeCcdCode]; opt; opt = opt->next()) {
     const char* sep = std::strchr(opt->arg, ':');
@@ -175,8 +190,8 @@ void convert(gemmi::Structure& st,
     gemmi::change_ccd_code(st, old_name, new_name);
   }
 
+  gemmi::setup_entities(st);
   if (st.input_format == CoorFormat::Pdb) {
-    gemmi::setup_entities(st);
     if (!options[SetSeq])
       gemmi::assign_label_seq_id(st, options[ForceLabel]);
     if (!options[CopyRemarks])
@@ -196,6 +211,8 @@ void convert(gemmi::Structure& st,
     gemmi::Op op = gemmi::parse_triplet(options[ApplySymop].arg);
     transform_pos_and_adp(st, st.cell.op_as_transform(op));
   }
+  if (options[Reframe])
+    standardize_crystal_frame(st);
 
   if (options[Biso]) {
     const char* start = options[Biso].arg;
@@ -243,14 +260,25 @@ void convert(gemmi::Structure& st,
                     chain.name + "\nTry option --shorten");
   }
   if (options[SetSeq]) {
-    gemmi::Ifstream stream(options[SetSeq].arg);
-    std::string seq = gemmi::read_pir_or_fasta(stream.ref());
-    for (gemmi::Entity& ent : st.entities)
-      if (ent.entity_type == gemmi::EntityType::Polymer) {
-        ent.full_sequence = gemmi::expand_protein_one_letter_string(seq);
-      }
+    std::vector<std::string> fasta_sequences;
+    for (const option::Option* opt = options[SetSeq]; opt; opt = opt->next()) {
+      gemmi::Ifstream stream(opt->arg);
+      std::string str = read_whole_file(stream.ref());
+      for (gemmi::FastaSeq& fs : gemmi::read_pir_or_fasta(str))
+        fasta_sequences.push_back(std::move(fs.seq));
+    }
+    if (options[Verbose])
+      std::cerr << fasta_sequences.size() << " sequence(s) was read..." << std::endl;
+    gemmi::clear_sequences(st);
+    gemmi::assign_best_sequences(st, fasta_sequences);
     gemmi::deduplicate_entities(st);
     gemmi::assign_label_seq_id(st, options[ForceLabel]);
+    for (gemmi::Entity& ent : st.entities) {
+      if (ent.entity_type == gemmi::EntityType::Polymer && ent.full_sequence.empty())
+        std::cerr << "No sequence found for "
+                  << polymer_type_to_string(ent.polymer_type) << " entity " << ent.name
+                  << " (" << gemmi::join_str(ent.subchains, ',') << ')' << std::endl;
+    }
   }
 
   if (options[SiftsNum]) {
@@ -348,8 +376,7 @@ void convert(gemmi::Structure& st,
     apply_cif_doc_modifications(doc, options);
 
     if (output_type == CoorFormat::Mmcif) {
-      auto style = cif_style_as_enum(options[CifStyle]);
-      write_cif_to_stream(os.ref(), doc, style);
+      write_cif_to_stream(os.ref(), doc, cif_write_options(options[CifStyle]));
     } else /*output_type == CoorFormat::Mmjson*/ {
       cif::JsonWriter writer(os.ref());
       writer.set_mmjson();
@@ -384,8 +411,12 @@ int GEMMI_MAIN(int argc, char **argv) {
   const char* output = p.nonOption(1);
 
   CoorFormat out_type = coor_format_as_enum(p.options[FormatOut]);
-  if (out_type == CoorFormat::Unknown)
-    out_type = gemmi::coor_format_from_ext_gz(output);
+  if (out_type == CoorFormat::Unknown) {
+    if (output[0] == '-' && output[1] == '\0')
+      out_type = CoorFormat::Pdb;
+    else
+      out_type = gemmi::coor_format_from_ext_gz(output);
+  }
   if (out_type == CoorFormat::ChemComp) {
     std::cerr << "The output format cannot be chemcomp.\n";
     return 1;
