@@ -237,12 +237,11 @@ void process_with_fft(const gemmi::Structure& st,
     fprintf(stderr, "Preparing electron density on a grid...\n");
     fflush(stderr);
   }
-  Timer timer(true);
+  Timer timer(verbose);
   timer.start();
   dencalc.set_grid_cell_and_spacegroup(st);
   dencalc.put_model_density_on_grid(st.models[0]);
-  if (verbose)
-    timer.print("...took");
+  timer.print("...took");
   if (map_file) {
     gemmi::Ccp4<Real> ccp4;
     ccp4.grid = dencalc.grid;
@@ -251,6 +250,11 @@ void process_with_fft(const gemmi::Structure& st,
   }
 
   if (verbose) {
+#if GEMMI_COUNT_DC
+    fprintf(stderr, "Density-points calculated: %zu (avg per atom: %g)\n",
+            dencalc.density_computations,
+            double(dencalc.density_computations) / dencalc.atoms_added);
+#endif
     fprintf(stderr, "FFT of grid %d x %d x %d\n",
             dencalc.grid.nu, dencalc.grid.nv, dencalc.grid.nw);
     fflush(stderr);
@@ -259,7 +263,7 @@ void process_with_fft(const gemmi::Structure& st,
   gemmi::FPhiGrid<Real> sf = transform_map_to_f_phi(dencalc.grid, /*half_l=*/true);
   if (verbose) {
     timer.print("...took");
-    fprintf(stderr, "Printing results...\n");
+    fprintf(stderr, "Preparing results...\n");
     fflush(stderr);
   }
   gemmi::StructureFactorCalculator<Table> calc(st.cell);
@@ -286,7 +290,7 @@ void process_with_fft(const gemmi::Structure& st,
   }
 
   if (scale_to.size() != 0) {
-    scaling.prepare_points(asu_data, scale_to, mask_data);
+    scaling.prepare_points(asu_data, scale_to, &mask_data);
     printf("Calculating scale factors using %zu points...\n", scaling.points.size());
     scaling.fit_isotropic_b_approximately();
     //fprintf(stderr, "k_ov=%g B_ov=%g\n", scaling.k_overall, scaling.get_b_overall().u11);
@@ -308,7 +312,7 @@ void process_with_fft(const gemmi::Structure& st,
       fprintf(stderr, "\n");
     }
   }
-  scaling.scale_data(asu_data, mask_data);
+  scaling.scale_data(asu_data, &mask_data);
 
   if (file.mode == RefFile::Mode::WriteMtz) {
     write_asudata_to_mtz(asu_data, file);
@@ -515,7 +519,7 @@ void process_with_table(bool use_st, gemmi::Structure& st, const gemmi::SmallStr
   const gemmi::UnitCell& cell = use_st ? st.cell : small.cell;
   gemmi::StructureFactorCalculator<Table> calc(cell);
 
-  // assign f' given explicitely in a file
+  // assign f' given explicitly in a file
   if (p.options[CifFp]) {
     if (use_st) {
       // _atom_type.scat_dispersion_real is almost never used,
@@ -802,13 +806,13 @@ void process(const std::string& input, const OptParser& p) {
     gemmi::fail("Electron scattering has no dispersive part (--ciffp)");
   if (table == 'x' || table == 'm') {
     if (p.options[NormalizeIt92])
-      gemmi::IT92<double>::normalize();
+      gemmi::IT92<float>::normalize();
     if (table == 'm')
-      gemmi::IT92<double>::ignore_charge = true;
-    process_with_table<gemmi::IT92<double>>(use_st, st, small, wavelength,
-                                            table == 'm', p);
+      gemmi::IT92<float>::ignore_charge = true;
+    process_with_table<gemmi::IT92<float>>(use_st, st, small, wavelength,
+                                           table == 'm', p);
   } else if (table == 'e') {
-    process_with_table<gemmi::C4322<double>>(use_st, st, small, 0., false, p);
+    process_with_table<gemmi::C4322<float>>(use_st, st, small, 0., false, p);
   } else if (table == 'n') {
     process_with_table<gemmi::Neutron92<double>>(use_st, st, small, 0., false, p);
   }
