@@ -4,16 +4,17 @@
 
 namespace gemmi {
 
-PolymerType check_polymer_type(const ConstResidueSpan& span) {
+PolymerType check_polymer_type(const ConstResidueSpan& span, bool ignore_entity_type) {
   if (span.empty())
     return PolymerType::Unknown;
-  size_t counts[ResidueInfo::ELS+1] = {0};
+  size_t counts[(int)ResidueKind::ELS+1] = {0};
   size_t aa = 0;
   size_t na = 0;
   size_t total = 0;
   bool has_atom_record = false;
   for (const Residue& r : span)
-    if (r.entity_type == EntityType::Unknown ||
+    if (ignore_entity_type ||
+        r.entity_type == EntityType::Unknown ||
         r.entity_type == EntityType::Polymer) {
       if (r.het_flag == 'A')
         has_atom_record = true;
@@ -25,13 +26,13 @@ PolymerType check_polymer_type(const ConstResidueSpan& span) {
         // (and almost never are in a polymer - except PO4, PO2 and AZI (N3)
         // which in a few PDB entries are included in polymers - but it
         // doesn't matter here).
-        if (info.kind == ResidueInfo::HOH || info.hydrogen_count == 0)
+        if (info.kind == ResidueKind::HOH || info.hydrogen_count == 0)
           continue;
         if (info.is_peptide_linking())
           ++aa;
         if (info.is_na_linking())
           ++na;
-        counts[info.kind]++;
+        counts[(int)info.kind]++;
       } else if (r.get_ca()) {
         ++aa;
       } else if (r.get_p()) {
@@ -49,12 +50,12 @@ PolymerType check_polymer_type(const ConstResidueSpan& span) {
   // ATOM records suggest a polymer, so weaken the condition for AA/NA polymers.
   size_t bonus = has_atom_record ? 1 : 0;
   if (2 * aa + bonus > total)
-    return counts[ResidueInfo::AA] >= counts[ResidueInfo::AAD]
+    return counts[(int)ResidueKind::AA] >= counts[(int)ResidueKind::AAD]
            ? PolymerType::PeptideL : PolymerType::PeptideD;
   if (2 * na + bonus > total) {
-    if (counts[ResidueInfo::DNA] == 0)
+    if (counts[(int)ResidueKind::DNA] == 0)
       return PolymerType::Rna;
-    if (counts[ResidueInfo::RNA] == 0)
+    if (counts[(int)ResidueKind::RNA] == 0)
       return PolymerType::Dna;
     return PolymerType::DnaRnaHybrid;
   }
@@ -115,7 +116,7 @@ void add_entity_types(Chain& chain, bool overwrite) {
       std::all_of(chain.residues.begin(), chain.residues.end(),
                   [](const Residue& r) { return r.entity_type != EntityType::Unknown; }))
     return;
-  PolymerType ptype = check_polymer_type(chain.whole());
+  PolymerType ptype = check_polymer_type(chain.whole(), /*ignore_entity_type=*/overwrite);
   auto it = chain.residues.begin();
   if (ptype != PolymerType::Unknown) {
     auto polymer_end = infer_polymer_end(chain, ptype);
@@ -355,7 +356,7 @@ void shorten_ccd_codes(Structure& st) {
       if (c1 > '9') {
         short_code[0] = c0++;
         c1 = '0';
-        if (c0 > 'Z')  // shoudn't happen
+        if (c0 > 'Z')  // shouldn't happen
           break;
       }
     }
