@@ -12,7 +12,7 @@ em++ --bind -O3 -Wall -Wextra -std=c++17 -I../../include \
     -s EXPORT_NAME=GemmiMtz \
     -s DISABLE_EXCEPTION_CATCHING=0 \
     -s ALLOW_MEMORY_GROWTH=1 \
-    -s 'EXTRA_EXPORTED_RUNTIME_METHODS=["writeArrayToMemory"]' \
+    -s 'EXPORTED_RUNTIME_METHODS=["writeArrayToMemory"]' \
     --pre-js pre.js \
     --no-entry \
     mtz_fft.cpp -o mtz.js \
